@@ -106,8 +106,7 @@ class SmappeeServiceLocation(object):
                                        serialnumber=ccc.get('serialNumber'),
                                        state_values=[
                                            {'id': 'ON_ON', 'name': 'on', 'current': ccc.get('relayStatus') is True},
-                                           {'id': 'OFF_OFF', 'name': 'off', 'current': ccc.get('relayStatus') is False}
-                                       ],
+                                           {'id': 'OFF_OFF', 'name': 'off', 'current': ccc.get('relayStatus') is False}],
                                        connection_state=ccc.get('connectionStatus').upper() if 'connectionStatus' in ccc else None,
                                        actuator_type=at)
 
@@ -119,9 +118,6 @@ class SmappeeServiceLocation(object):
                         self.has_solar_production = True
 
         else:
-            # Collect service location info
-            sl_info = self.smappee_api.get_service_location_info(service_location_id=self.service_location_id)
-
             # Collect metering configuration
             sl_metering_configuration = self.smappee_api.get_metering_configuration(service_location_id=self.service_location_id)
 
@@ -144,9 +140,6 @@ class SmappeeServiceLocation(object):
 
             # Load actuators (Smappee Switches, Comfort Plugs, IO modules)
             for actuator in sl_metering_configuration.get('actuators'):
-                # temp disable IO modules until 1.6.0 release
-                if actuator.get('type') == 'INFINITY_OUTPUT_MODULE':
-                    continue
                 self._add_actuator(id=actuator.get('id'),
                                    name=actuator.get('name'),
                                    serialnumber=actuator.get('serialNumber') if 'serialNumber' in actuator else None,
